%global pkgvers 0
%global scdate0 20230811
%global schash0 a015afec811128afc79ef28230d4b9ca9aabd867
%global branch0 master
%global source0 https://github.com/analogdevicesinc/libiio.git

%global sshort0 %{expand:%%{lua:print(('%{schash0}'):sub(1,8))}}

Name:           libiio
Version:        0.25
Release:        %{scdate0}.%{pkgvers}.git%{sshort0}%{?dist}
Summary:        Library for Industrial IO
License:        LGPLv2

URL:            https://analogdevicesinc.github.io/libiio

BuildRequires:  gcc cmake git doxygen flex bison python3
BuildRequires:  python3-devel python3-setuptools python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme libxml2-devel python3
BuildRequires:  libusbx-devel avahi-devel libaio-devel
%if 0%{?fedora}
BuildRequires:  libserialport-devel
%endif

%global __cmake_in_source_build 1


%description
Library for interfacing with Linux IIO devices

libiio is used to interface to Linux Industrial Input/Output (IIO) Subsystem.
The Linux IIO subsystem is intended to provide support for devices that in some 
sense are analog to digital or digital to analog converters (ADCs, DACs). This 
includes, but is not limited to ADCs, Accelerometers, Gyros, IMUs, Capacitance 
to Digital Converters (CDCs), Pressure Sensors, Color, Light and Proximity 
Sensors, Temperature Sensors, Magnetometers, DACs, DDS (Direct Digital 
Synthesis), PLLs (Phase Locked Loops), Variable/Programmable Gain Amplifiers 
(VGA, PGA), and RF transceivers.

%package        utils
Summary:        Utilities for Industrial IO
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    utils
Utilities for accessing IIO using libiio

%package        devel
Summary:        Development package for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
Files for development with %{name}.

%package        doc
Summary:        Development documentation for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    doc
Documentation for development with %{name}.

%package -n     python3-iio
Summary: Python 3 bindings for Industrial IO (libiio)
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n python3-iio
Python 3 bindings for Industrial IO


%prep
%setup -T -c -n %{name}
find %{_builddir} -name SPECPARTS -exec rm -rf {} +
git clone --depth 1 -n -b %{branch0} %{source0} .
git fetch --depth 1 origin %{schash0}
git reset --hard %{schash0}
git log --format=fuller


%build
sed -i 's/${LIBIIO_VERSION_MAJOR}-doc//' CMakeLists.txt
%cmake -Wno-dev . \
       -DCMAKE_SKIP_RPATH=ON \
       -DCMAKE_VERBOSE_MAKEFILE=OFF \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DPYTHON_BINDINGS=ON -DWITH_DOC=ON
%cmake_build


%install
%cmake_install
find %{buildroot} -name '*.la' -delete


%ldconfig_scriptlets


%files
%license COPYING.txt
%{_libdir}/%{name}.so.*
/lib/udev/rules.d/90-libiio.rules

%files utils
%{_bindir}/iio_*
%{_sbindir}/iiod

%files devel
%{_includedir}/iio.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{name}.so

%files doc
%doc %{_docdir}/%{name}

%files -n python3-iio
%{python3_sitelib}/__pycache__/iio*
%{python3_sitelib}/iio.py
%{python3_sitelib}/pylibiio*


%changelog
* Tue Aug 25 2020 Balint Cristian <cristian.balint@gmail.com>
- github update releases
